/**
 * @file
 *
 * @todo make a block instead of relying on a theme function.
 */

(function (Drupal, $) {

  var override;

  /**
   * Add the DOM element with the controls for the install screen.
   *
   * Override to change where the prompt is added in the DOM.
   *
   * @type {{attach: Drupal.pwaBeforeInstall.attach}}
   */
  Drupal.behaviors.pwaBeforeInstall = {
    attach: function (context, settings) {
      var $body = $('body');
      if (!$body.once('pwa-beforeinstallprompt').length) {
        return;
      }

      override = Drupal.theme('beforeinstallprompt');
      if (!override) {
        return;
      }
      $body.append(override);
    }
  };

  /**
   * Override to provide a custom installation experience.
   *
   * The theme function MUST return an element with a
   * 'data-drupal-pwa-install-button' attribute.
   *
   * @return {string|boolean|undefined}
   *   If the theme function returns false, the install prompt will be disabled
   *   Returning undefined will keep the native behavior.
   */
  Drupal.theme.beforeinstallprompt = function () {
    // Display a custom message for install.
    //return '<div class="prompt">Add to homescreen <button type="button" data-drupal-pwa-install-button>Add</button></div>';

    // Disable the install prompt
    //return false;

    // Use default browser behavior
    return;
  };

  // Show the users' prompt instead of the default UI.
  window.addEventListener('beforeinstallprompt', function (event) {
    // keep the event to trigger it later.
    var installPrompt = event;

    // Use the default browser behavior.
    if (typeof override === 'undefined') {
      return;
    }

    // Prevent the default UI from appearing on mobile
    event.preventDefault();

    // Disable the install prompt.
    if (override === false) {
      return;
    }

    // Register what is necessary for a custom install prompt.
    installPrompt.userChoice.then(function (choice) {
      if (choice.outcome === 'accepted') {
        console.log('User accepted the A2HS prompt');
      }
      else {
        console.log('User dismissed the A2HS prompt');
      }
    });

    $('[data-drupal-pwa-install-button]').one('click', function () {
      installPrompt.prompt();
    });
  });

}(Drupal, jQuery));
