/**
 * @file
 *
 * Triggers a push notification subscription on page load.
 */

(function (Drupal, navigator) {

  // Listen to permissions changes and update Drupal backend accordingly.
  navigator.permissions.query({name: 'notifications'}).then((result) => {
    var webpush = Drupal.pwa.webpush;
    var sub = webpush.subscription;
    result.addEventListener('change', function (event) {
      // Permission was granted, automatically register the push notifications.
      if (event.target.state === 'granted') {
        webpush.subscribe()
          .then(function () { console.debug('PWA - Permissions: granted, subscribed to push notifications'); })
          .catch(function (error) { console.warn('PWA - Permissions:', error); });
      }
      // Permission was not granted, remove the subscription from Drupal.
      else if (sub.sha256) {
        console.log('PWA - Permission removed. Remove subscription from Drupal.');
        sub.delete(sub.sha256);
      }
    });
  });

  // Wait for page load to check registration status, that allows other modules to override
  // methods.
  if (Notification.permission === 'granted') {
    window.addEventListener('load', function () {
      // If permission is already granted for notifications, register directly.
      Drupal.pwa.webpush.subscribe()
        .then(function () { console.debug('PWA - Autoregister: Subscribed to push notifications'); })
        .catch(function (error) { console.warn('PWA - Autoregister:', error); });
    });
  }

}(Drupal, navigator));
